==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/fi/base.php <==
<?php

return [
    '<strong>Confirm</strong> post deletion' => '<strong>Vahvista</strong> julkaisun poistaminen',
    '<strong>Move</strong> content' => '<strong>Siirrä</strong> sisältöä',
    '<strong>Permalink</strong> to this post' => '<strong>Pysyvä</strong> linkki tähän viestiin',
    'Activated' => 'Aktivoitu',
    'Add a member to notify' => 'Lisää käyttäjä jolle ilmoitetaan',
    'Archived' => 'Arkistoitu',
    'Back to stream' => 'Takaisin',
    'Cancel' => 'Peruuta',
    'Cancel Edit' => 'Peruuta Muokkaus',
    'Change to "Private"' => 'Piilota',
    'Change to "Public"' => 'Julkaise',
    'Configure' => 'Hallitse',
    'Confirm' => 'Vahvista',
    'Content' => 'Sisältö',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Sisällön tunniste, on virheellinen. <strong>contentcontainer_id</strong>',
    'Content has been moved to {spacename}' => 'Sisältö on siiretty sivulle {spacename}',
    'Could not find requested content!' => 'Pyydettyä sisältöä ei löytynyt!',
    'Created by me' => 'Minun luomat',
    'Creation time' => 'Luomisaika',
    'Delete' => 'Poista',
    'Deleted' => 'Poistettu',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'Haluatko todella poistaa tämän julkaisun? Kaikki tykkäykset ja kommentit poistetaan!',
    'Edit' => 'Muokkaa',
    'Enable' => 'Ota käyttöön',
    'Filter' => 'Suodatin',
    'I\'m involved' => 'Missä olen mukana',
    'Invalid content id given!' => 'Virheellinen sisällön tunnus!',
    'Invalid request method!' => 'Virheellinen pyyntötapa!',
    'Invalid space selection.' => 'Väärä sivu valittu.',
    'Last update' => 'Äskettäin päivitetty',
    'Load more' => 'Lataa lisää',
    'Move content' => 'Siirrä',
    'Move to archive' => 'Siirrä arkistoon',
    'No matches with your selected filters!' => 'Ei tuloksia valitulla suodattimella!',
    'None' => 'Ei mitään',
    'Nothing here yet!' => 'Täällä ei ole vielä mitään',
    'Notify members' => 'Ilmoita jäsenille',
    'Permalink' => 'Kopioi linkki',
    'Pin to top' => 'Kiinnitä ylös',
    'Pinned' => 'Kiinitetty',
    'Private' => 'Yksityinen',
    'Public' => 'Julkinen',
    'Submit' => 'Vahvista',
    'Tag' => 'Tägi',
    'Target Space' => 'Kohde',
    'The author of this content is not allowed to create private content within the selected space.' => 'Sivun ylläpitäjä ei ole antanut sinulle oikeuksia julkaista yksityistä sisältöä tällä sivulla.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Sivun ylläpitäjä ei ole antanut sinulle oikeuksia julkaista julkista sisältöä tällä sivulla.',
    'The content can\'t be moved to its current space.' => 'Sisältöä ei voi siirtää tälle sivulle',
    'The content has been archived.' => 'Julkaisu arkistoitiin',
    'The content has been deleted.' => 'Julkaisu poistettiin',
    'The content has been unarchived.' => 'Julkasisu poistettiin arkistoista',
    'The given name is already in use.' => 'Annettu nimi on jo käytössä.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Laajennus {moduleName} ei ole käytössä tällä sivulla.',
    'This action is disabled!' => 'Tämä toiminto on poistettu käytöstä!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Tätä sisältötyyppiä ei voi siirtää laajennuksen tunnuksen puuttumisen vuoksi.',
    'This content type can\'t be moved.' => 'Tätä sisältöä ei voi siirtää.',
    'This space is archived.' => 'Tämä sivu on arkistoitu.',
    'This space is not visible!' => 'Tämä sivu ei ole julkinen',
    'Topics' => 'Aiheet',
    'Turn off notifications' => 'Laita ilmoitukset pois',
    'Turn on notifications' => 'Laita ilmoitukset päälle',
    'Unarchive' => 'Poista arkistosta',
    'Unpin' => 'Poista kiinnitys',
    'Updated' => 'Päivitetty',
    'With attachments' => 'Sisältää liiteitä',
    'You do not have the permission to move this content to the given space.' => 'Sinulla ei ole oikeuksia siirtää tätä sisältöä tälle sivulle.',
    'You do not have the permission to move this content.' => 'Sinulla ei ole oikeuksia siirtää tätä sisältöä.',
    'Your last edit state has been saved!' => 'Viimeisin toiminto tallennettiin!',
    'in' => '@@',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/fi/base.php <==
<?php

return [
    '<strong>Move</strong> content' => '<strong>Siirrä</strong> sisältöä',
    '<strong>Permalink</strong> to this post' => '<strong>Pysyvä</strong> linkki tähän viestiin',
    'Activated' => 'Aktivoitu',
    'Add a member to notify' => 'Lisää käyttäjä jolle ilmoitetaan',
    'Archived' => 'Arkistoitu',
    'Back to stream' => 'Takaisin',
    'Cancel' => 'Peruuta',
    'Cancel Edit' => 'Peruuta Muokkaus',
    'Change to "Private"' => 'Piilota',
    'Change to "Public"' => 'Julkaise',
    'Configure' => 'Hallitse',
    'Confirm' => 'Vahvista',
    'Content' => 'Sisältö',
    'Content Tag with invalid contentcontainer_id assigned.' => 'Sisällön tunniste, on virheellinen. <strong>contentcontainer_id</strong>',
    'Content has been moved to {spacename}' => 'Sisältö on siiretty sivulle {spacename}',
    'Could not find requested content!' => 'Pyydettyä sisältöä ei löytynyt!',
    'Created by me' => 'Minun luomat',
    'Creation time' => 'Luomisaika',
    'Delete' => 'Poista',
    'Deleted' => 'Poistettu',
    'Edit' => 'Muokkaa',
    'Enable' => 'Ota käyttöön',
    'Filter' => 'Suodatin',
    'I\'m involved' => 'Missä olen mukana',
    'Invalid content id given!' => 'Virheellinen sisällön tunnus!',
    'Invalid request method!' => 'Virheellinen pyyntötapa!',
    'Invalid space selection.' => 'Väärä sivu valittu.',
    'Last update' => 'Äskettäin päivitetty',
    'Load more' => 'Lataa lisää',
    'Move content' => 'Siirrä',
    'Move to archive' => 'Siirrä arkistoon',
    'No matches with your selected filters!' => 'Ei tuloksia valitulla suodattimella!',
    'None' => 'Ei mitään',
    'Nothing here yet!' => 'Täällä ei ole vielä mitään',
    'Notify members' => 'Ilmoita jäsenille',
    'Permalink' => 'Kopioi linkki',
    'Pin to top' => 'Kiinnitä ylös',
    'Pinned' => 'Kiinitetty',
    'Private' => 'Yksityinen',
    'Public' => 'Julkinen',
    'Submit' => 'Vahvista',
    'Tag' => 'Tägi',
    'Target Space' => 'Kohde',
    'The author of this content is not allowed to create private content within the selected space.' => 'Sivun ylläpitäjä ei ole antanut sinulle oikeuksia julkaista yksityistä sisältöä tällä sivulla.',
    'The author of this content is not allowed to create public content within the selected space.' => 'Sivun ylläpitäjä ei ole antanut sinulle oikeuksia julkaista julkista sisältöä tällä sivulla.',
    'The content can\'t be moved to its current space.' => 'Sisältöä ei voi siirtää tälle sivulle',
    'The content has been archived.' => 'Julkaisu arkistoitiin',
    'The content has been deleted.' => 'Julkaisu poistettiin',
    'The content has been unarchived.' => 'Julkasisu poistettiin arkistoista',
    'The given name is already in use.' => 'Annettu nimi on jo käytössä.',
    'The module {moduleName} is not enabled on the selected target space.' => 'Laajennus {moduleName} ei ole käytössä tällä sivulla.',
    'This action is disabled!' => 'Tämä toiminto on poistettu käytöstä!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'Tätä sisältötyyppiä ei voi siirtää laajennuksen tunnuksen puuttumisen vuoksi.',
    'This content type can\'t be moved.' => 'Tätä sisältöä ei voi siirtää.',
    'This space is archived.' => 'Tämä sivu on arkistoitu.',
    'This space is not visible!' => 'Tämä sivu ei ole julkinen',
    'Topics' => 'Aiheet',
    'Turn off notifications' => 'Laita ilmoitukset pois',
    'Turn on notifications' => 'Laita ilmoitukset päälle',
    'Unarchive' => 'Poista arkistosta',
    'Unpin' => 'Poista kiinnitys',
    'Updated' => 'Päivitetty',
    'With attachments' => 'Sisältää liiteitä',
    'You do not have the permission to move this content to the given space.' => 'Sinulla ei ole oikeuksia siirtää tätä sisältöä tälle sivulle.',
    'You do not have the permission to move this content.' => 'Sinulla ei ole oikeuksia siirtää tätä sisältöä.',
    'Your last edit state has been saved!' => 'Viimeisin toiminto tallennettiin!',
    'in' => '@@',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
